@@ -25,7 +25,7 @@ class Lasso(Lasso_sklearn):
 
     The optimization objective for Lasso is::
 
-    (1 / (2 * n_samples)) * ||y - X w||^2_2 + alpha * ||w||_1
+    (1 / (2 * n_samples)) * ||y - X w||^2_2 + alpha * \sum_j weights_j |w_j|
 
     Parameters
     ----------
@@ -58,6 +58,10 @@ class Lasso(Lasso_sklearn):
     fit_intercept : bool, optional (default=True)
         Whether or not to fit an intercept.
 
+    weights : array, shape (n_features,), optional (default=None)
+        Weights used in the L1 penalty part of the Lasso objective.
+        If None, weights equal to 1 are used.
+
     normalize : bool, optional (default=False)
         This parameter is ignored when ``fit_intercept`` is set to False.
         If True,  the regressors X will be normalized before regression by
@@ -110,7 +114,8 @@ class Lasso(Lasso_sklearn):
 
     def __init__(self, alpha=1., max_iter=100, max_epochs=50000, p0=10,
                  verbose=0, tol=1e-4, prune=True, fit_intercept=True,
-                 normalize=False, warm_start=False, positive=False):
+                 weights=None, normalize=False, warm_start=False,
+                 positive=False):
         super(Lasso, self).__init__(
             alpha=alpha, tol=tol, max_iter=max_iter,
             fit_intercept=fit_intercept, normalize=normalize,
@@ -120,6 +125,7 @@ class Lasso(Lasso_sklearn):
         self.p0 = p0
         self.prune = prune
         self.positive = positive
+        self.weights = weights
 
     def path(self, X, y, alphas, coef_init=None, return_n_iter=True, **kwargs):
         """Compute Lasso path with Celer."""
@@ -127,8 +133,8 @@ class Lasso(Lasso_sklearn):
             X, y, "lasso", alphas=alphas, coef_init=coef_init,
             max_iter=self.max_iter, return_n_iter=return_n_iter,
             max_epochs=self.max_epochs, p0=self.p0, verbose=self.verbose,
-            tol=self.tol, prune=self.prune, positive=self.positive,
-            X_scale=kwargs.get('X_scale', None),
+            tol=self.tol, prune=self.prune, weights=self.weights,
+            positive=self.positive, X_scale=kwargs.get('X_scale', None),
             X_offset=kwargs.get('X_offset', None))
 
         return results
@@ -930,7 +936,7 @@ class GroupLassoCV(LassoCV, sklearn_LinearModelCV):
     p0 : int, optional (default=10)
         Number of features in the first working set.
 
-    prune : bool, optional (default=False)
+    prune : bool, optional (default=True)
         Whether to use pruning when growing the working sets.
 
     precompute : ignored parameter, kept for sklearn compatibility.
@@ -986,6 +992,7 @@ class GroupLassoCV(LassoCV, sklearn_LinearModelCV):
         self.max_epochs = max_epochs
         self.p0 = p0
         self.prune = prune
+        self.precompute = precompute
 
     def path(self, X, y, alphas, coef_init=None, **kwargs):
         """Compute GroupLasso path with Celer."""
